@@ -23,16 +23,17 @@ import logging
 import subprocess
 
 from requests.packages.urllib3.util import retry
-from fedora_messaging.config import conf
 from fedora_messaging.api import publish as fm_publish
-from fedora_messaging.exceptions import PublishReturned, ConnectionException
+from fedora_messaging.exceptions import PublishReturned, ConnectionException, Nack
 from fedora_messaging.message import Message
+from anitya_schema.project_messages import ProjectMapCreated, ProjectVersionUpdated
 
 import requests
-import yaml
 import fedmsg
+import xmlrpc
 
 from hotness import exceptions
+from hotness.config import config as hotness_config
 import hotness.anitya
 import hotness.buildsys
 import hotness.bz
@@ -60,49 +61,39 @@ class BugzillaTicketFiler(object):
     """
 
     def __init__(self):
-
-        # This is just convenient.
-        self.config = conf["consumer_config"]
-
         self.bugzilla = hotness.bz.Bugzilla(
-            consumer=self, config=self.config["bugzilla"]
+            consumer=self, config=hotness_config["bugzilla"]
+        )
+        self.buildsys = hotness.buildsys.Koji(
+            consumer=self, config=hotness_config["koji"]
         )
-        self.buildsys = hotness.buildsys.Koji(consumer=self, config=self.config["koji"])
 
-        default = "https://pagure.io/releng/fedora-scm-requests"
-        self.repo_url = self.config.get("repo_url", default)
-        default = "https://pdc.fedoraproject.org"
-        self.pdc_url = self.config.get("pdc_url", default)
-        default = "https://src.fedoraproject.org"
-        self.dist_git_url = self.config.get("dist_git_url", default)
+        self.pdc_url = hotness_config["pdc_url"]
+        self.dist_git_url = hotness_config["dist_git_url"]
 
-        anitya_config = self.config.get("anitya", {})
-        default = "https://release-monitoring.org"
-        self.anitya_url = anitya_config.get("url", default)
-        self.anitya_username = anitya_config.get("username", default)
-        self.anitya_password = anitya_config.get("password", default)
+        self.anitya_url = hotness_config["anitya"]["url"]
 
         # Also, set up our global cache object.
         _log.info("Configuring cache.")
         with hotness.cache.cache_lock:
             if not hotness.cache.cache.is_configured:
-                hotness.cache.cache.configure(**self.config["cache"])
+                hotness.cache.cache.configure(**hotness_config["cache"])
 
-        self.mdapi_url = self.config.get("mdapi_url")
+        self.mdapi_url = hotness_config["mdapi_url"]
         _log.info("Using hotness.mdapi_url=%r" % self.mdapi_url)
-        self.repoid = self.config.get("repoid", "rawhide")
+        self.repoid = hotness_config["repoid"]
         _log.info("Using hotness.repoid=%r" % self.repoid)
-        self.distro = self.config.get("distro", "Fedora")
+        self.distro = hotness_config["distro"]
         _log.info("Using hotness.distro=%r" % self.distro)
 
         # Retrieve the requests configuration; by default requests time out
         # after 15 seconds and are retried up to 3 times.
         self.requests_session = requests.Session()
         self.timeout = (
-            self.config.get("connect_timeout", 15),
-            self.config.get("read_timeout", 15),
+            hotness_config["connect_timeout"],
+            hotness_config["read_timeout"],
         )
-        retries = self.config.get("hotness.requests_retries", 3)
+        retries = hotness_config["requests_retries"]
         retry_conf = retry.Retry(
             total=retries, connect=retries, read=retries, backoff_factor=1
         )
@@ -127,14 +118,14 @@ class BugzillaTicketFiler(object):
 
     def publish(self, topic, msg):
         """
-        Publish a feora-messaging message to the specified topic.
+        Publish a fedora-messaging message to the specified topic.
 
         Args:
             topic (str): Topic to publish to
             msg (dict): Message to be send
         """
         _log.info("publishing topic %r" % topic)
-        if self.config["legacy_messaging"]:
+        if hotness_config["legacy_messaging"]:
             fedmsg.publish(modname="hotness", topic=topic, msg=msg)
         else:
             try:
@@ -154,13 +145,15 @@ class BugzillaTicketFiler(object):
             msg (fedora_messaging.message.Message) The message we received
                 from the queue.
         """
-        topic, body, msg_id = msg.topic, msg._body, msg.id
+        topic, body, msg_id = msg.topic, msg.body, msg.id
         _log.debug("Received %r" % msg_id)
 
         if topic.endswith("anitya.project.version.update"):
-            self.handle_anitya_version_update(msg)
+            message = ProjectVersionUpdated(topic=msg.topic, body=msg.body)
+            self.handle_anitya_version_update(message)
         elif topic.endswith("anitya.project.map.new"):
-            self.handle_anitya_map_new(msg)
+            message = ProjectMapCreated(topic=msg.topic, body=msg.body)
+            self.handle_anitya_map_new(message)
         elif topic.endswith("buildsys.task.state.change"):
             self.handle_buildsys_scratch(msg)
         else:
@@ -181,28 +174,24 @@ class BugzillaTicketFiler(object):
         Publishes to ``update.drop`` if there is no mapping to a package in
         Fedora.
         """
-        body, msg_id = msg._body, msg.id
-        _log.info("Handling anitya msg %r" % msg_id)
-        # First, What is this thing called in our distro?
-        # (we do this little inner.get(..) trick to handle legacy messages)
-        inner = body.get("message")
-        if self.distro not in [p["distro"] for p in inner["packages"]]:
+        _log.info("Handling anitya msg %r" % msg.id)
+        if self.distro not in msg.distros:
             _log.info(
-                "No %r mapping for %r.  Dropping."
-                % (self.distro, body["message"]["project"]["name"])
+                "No %r mapping for %r. Dropping." % (self.distro, msg.project_name)
             )
-            self.publish("update.drop", msg=dict(trigger=msg, reason="anitya"))
+            trigger = {"msg": msg.body, "topic": msg.topic}
+            self.publish("update.drop", msg=dict(trigger=trigger, reason="anitya"))
             return
 
         # Sometimes, an upstream is mapped to multiple fedora packages
         # File a bug on each one...
         # https://github.com/fedora-infra/the-new-hotness/issues/33
-        for package in inner["packages"]:
+        for package in msg.mappings:
             if package["distro"] == self.distro:
                 pname = package["package_name"]
 
-                upstream = inner["upstream_version"]
-                self._handle_anitya_update(upstream, pname, body)
+                upstream = msg.project_version
+                self._handle_anitya_update(upstream, pname, msg)
 
     def handle_anitya_map_new(self, msg):
         """
@@ -215,17 +204,15 @@ class BugzillaTicketFiler(object):
 
         Topic: 'org.release-monitoring.prod.anitya.project.map.new'
         """
-        message = msg["msg"]["message"]
-        if message["distro"] != self.distro:
+        if msg.distro != self.distro:
             _log.info(
-                "New mapping on %s, not for %s.  Dropping."
-                % (message["distro"], self.distro)
+                "New mapping on %s, not for %s. Dropping." % (msg.distro, self.distro)
             )
             return
 
-        project = message["project"]
-        package = message["new"]
-        upstream = msg["msg"]["project"]["version"]
+        project = msg.project_name
+        package = msg.package_name
+        upstream = msg.project_version
 
         _log.info(
             "Newly mapped %r to %r bears version %r" % (project, package, upstream)
@@ -236,11 +223,12 @@ class BugzillaTicketFiler(object):
         else:
             _log.info("Forcing an anitya upstream check.")
             anitya = hotness.anitya.Anitya(self.anitya_url)
-            anitya.force_check(msg["msg"]["project"])
+            anitya.force_check(msg.project_id)
 
     def _handle_anitya_update(self, upstream, package, msg):
-        url = msg["project"]["homepage"]
-        projectid = msg["project"]["id"]
+        trigger = {"msg": msg.body, "topic": msg.topic}
+        url = msg.project_homepage
+        projectid = msg.project_id
 
         # Is it something that we're being asked not to act on?
         is_monitored = self.is_monitored(package)
@@ -253,7 +241,7 @@ class BugzillaTicketFiler(object):
             # Unfortunately it's not in mdapi, we can't do much about it
             _log.warning("No koji version found for %r" % package)
             if is_monitored:
-                self.publish("update.drop", msg=dict(trigger=msg, reason="rawhide"))
+                self.publish("update.drop", msg=dict(trigger=trigger, reason="rawhide"))
             return
         js = r.json()
         version = js["version"]
@@ -269,26 +257,40 @@ class BugzillaTicketFiler(object):
             _log.info("OK, %s is newer than %s-%s" % (upstream, version, release))
 
             if not is_monitored:
-                _log.info("repo says not to monitor %r.  Dropping." % package)
-                self.publish("update.drop", msg=dict(trigger=msg, reason="pkgdb"))
+                _log.info("repo says not to monitor %r. Dropping." % package)
+                self.publish("update.drop", msg=dict(trigger=trigger, reason="pkgdb"))
                 return
 
-            bz = self.bugzilla.handle(
-                projectid, package, upstream, version, release, url
-            )
+            bz = None
+
+            try:
+                bz = self.bugzilla.handle(
+                    projectid, package, upstream, version, release, url
+                )
+            # Raise Fedora messaging NACK exception when there is issue in bugzilla client
+            except xmlrpc.client.Fault as e:
+                _log.warn(
+                    "Encountered an error during searching Bugzilla issue for '{0}': {1}".format(
+                        package, e.faultString
+                    )
+                )
+                raise Nack
+
             if not bz:
-                _log.info("No RHBZ change detected (odd).  Aborting.")
-                self.publish("update.drop", msg=dict(trigger=msg, reason="bugzilla"))
+                _log.info("No RHBZ change detected (odd). Aborting.")
+                self.publish(
+                    "update.drop", msg=dict(trigger=trigger, reason="bugzilla")
+                )
                 return
 
             self.publish(
                 "update.bug.file",
-                msg=dict(trigger=msg, bug=dict(bug_id=bz.bug_id), package=package),
+                msg=dict(trigger=trigger, bug=dict(bug_id=bz.bug_id), package=package),
             )
             _log.info("Filed Bugzilla #%i" % bz.bug_id)
 
             if is_monitored == "nobuild":
-                _log.info("Monitor flag set to 'nobuild'.  " "Skipping scratch build.")
+                _log.info("Monitor flag set to 'nobuild'. Skipping scratch build.")
                 return
 
             try:
@@ -333,19 +335,20 @@ class BugzillaTicketFiler(object):
 
         Topic: 'org.fedoraproject.prod.buildsys.task.state.change'
         """
-        instance = msg["msg"]["instance"]
+        msg_id, body = msg.id, msg.body
+        instance = body["instance"]
 
         if instance != "primary":
             _log.debug("Ignoring secondary arch task...")
             return
 
-        method = msg["msg"]["method"]
+        method = body["method"]
 
         if method != "build":
             _log.debug("Ignoring non-build task...")
             return
 
-        task_id = msg["msg"]["info"]["id"]
+        task_id = body["info"]["id"]
         if task_id not in self.scratch_builds:
             _log.debug(
                 "Ignoring [%s] as it's not one of our %d outstanding "
@@ -353,7 +356,7 @@ class BugzillaTicketFiler(object):
             )
             return
 
-        _log.info("Handling koji scratch msg %r" % msg.get("msg_id"))
+        _log.info("Handling koji scratch msg %r" % msg_id)
 
         # see koji.TASK_STATES for all values
         done_states = {
@@ -361,14 +364,14 @@ class BugzillaTicketFiler(object):
             "FAILED": "failed",
             "CANCELED": "canceled",
         }
-        state = msg["msg"]["new"]
+        state = body["new"]
         if state not in done_states:
             return
 
         bugs = []
 
-        url = fedmsg.meta.msg2link(msg, **self.hub.config)
-        subtitle = fedmsg.meta.msg2subtitle(msg, **self.hub.config)
+        url = hotness.buildsys.link(msg)
+        subtitle = hotness.buildsys.subtitle(msg)
         text = "%s %s" % (subtitle, url)
 
         # Followup on bugs we filed
@@ -377,17 +380,17 @@ class BugzillaTicketFiler(object):
         # Also follow up on Package Review requests, but only if the package is
         # not already in Fedora (it would be a waste of time to query bugzilla
         # if the review is already approved and scm has been processed).
-        package_name = "-".join(msg["msg"]["srpm"].split("-")[:-2])
+        package_name = "-".join(body["srpm"].split("-")[:-2])
         if package_name and not self.in_dist_git(package_name):
             for bug in self.bugzilla.review_request_bugs(package_name):
                 bugs.append((bug, text))
 
         if not bugs:
-            _log.debug("No bugs to update for %r" % msg.get("msg_id"))
+            _log.debug("No bugs to update for %r" % msg_id)
             return
 
     def is_monitored(self, package):
-        """ Returns True if a package is marked as 'monitored' in git.
+        """Returns True if a package is marked as 'monitored' in git.
 
         This is a thin wrapper around a requests.get call and could raise any
         exceptions raised by that function.
@@ -399,7 +402,7 @@ class BugzillaTicketFiler(object):
             _log.info("Package %s is retired.  Ignoring monitoring." % package)
             return False
 
-        url = "{0}/raw/master/f/rpms/{1}".format(self.repo_url, package)
+        url = "{0}/_dg/anitya/rpms/{1}".format(self.dist_git_url, package)
         _log.debug("Checking %r to see if %s is monitored." % (url, package))
         r = self.requests_session.get(url, timeout=self.timeout)
 
@@ -408,7 +411,7 @@ class BugzillaTicketFiler(object):
             return False
 
         try:
-            data = yaml.safe_load(r.text)
+            data = r.json()
             string_value = data.get("monitoring", "no-monitoring")
             return_values = {
                 "monitoring": "nobuild",
@@ -421,7 +424,7 @@ class BugzillaTicketFiler(object):
             return False
 
     def is_retired(self, package):
-        """ Returns True if a package is marked as 'retired' in PDC.
+        """Returns True if a package is marked as 'retired' in PDC.
 
         This is a thin wrapper around a requests.get call and could raise any
         exceptions raised by that function.
@@ -441,7 +444,7 @@ class BugzillaTicketFiler(object):
 
     @hotness.cache.cache.cache_on_arguments()
     def in_dist_git(self, package):
-        """ Returns True if a package is in the Fedora dist-git.
+        """Returns True if a package is in the Fedora dist-git.
 
         This is a thin wrapper around a requests.head call and could raise any
         exceptions raised by that function.
